/**************************************************************************
 |                                                                         
 |                    STATA SETUP FILE FOR ICPSR 02884
 |        NATIONAL TREATMENT IMPROVEMENT EVALUATION STUDY (NTIES),
 |                               1992-1997
 |            (DATASET 0005: NTIES CLINICAL UNIT DATA (NCLU))
 |
 |
 |  Please edit this file as instructed below.
 |  To execute, start Stata, change to the directory containing:
 |       - this do file
 |       - the ASCII data file
 |       - the dictionary file
 |
 |  Then execute the do file (e.g., do 02884-0005-statasetup.do)
 |
 **************************************************************************/

set mem 7m  /* Allocating 7 megabyte(s) of RAM for Stata SE to read the
                 data file into memory. */


set more off  /* This prevents the Stata output viewer from pausing the
                 process */

/****************************************************

Section 1: File Specifications
   This section assigns local macros to the necessary files.
   Please edit:
        "data-filename" ==> The name of data file downloaded from ICPSR
        "dictionary-filename" ==> The name of the dictionary file downloaded.
        "stata-datafile" ==> The name you wish to call your Stata data file.

   Note:  We assume that the raw data, dictionary, and setup (this do file) all
          reside in the same directory (or folder).  If that is not the case
          you will need to include paths as well as filenames in the macros.

********************************************************/

local raw_data "data-filename"
local dict "dictionary-filename"
local outfile "stata-datafile"

/********************************************************

Section 2: Infile Command

This section reads the raw data into Stata format.  If Section 1 was defined
properly, there should be no reason to modify this section.  These macros
should inflate automatically.

**********************************************************/

infile using `dict', using (`raw_data') clear


/*********************************************************

Section 3: Value Label Definitions
This section defines labels for the individual values of each variable.
We suggest that users do not modify this section.

**********************************************************/


label data "National Treatment Improvement Evaluation Study (NTIES), 1992-1997, NTIES Clinical Unit Data (NCLU)"

#delimit ;
label define DIRCOLL   -9 "NO DATA" 1 "Yes" 2 "No" ;
label define DIRGRAD   -9 "NO DATA" 1 "Yes" 2 "No" ;
label define DIRCRED   -9 "NO DATA" 1 "Yes" 2 "No" ;
label define DIRYEARS  -9 "NO DATA" 1 "0-4" 2 "5 or more" ;
label define DIRSEX    -9 "NO DATA" 1 "Male" 2 "Female" ;
label define DIRETHNI  -9 "NO DATA" 1 "Yes" 2 "No" ;
label define YRSKEYP1  -9 "NO DATA" -3 "MISSING" 1 "0-2 years" 2 "3-6 years"
                       3 "7+ years" ;
label define YRSKEYP2  -9 "NO DATA" 1 "0-2 years" 2 "3-6 years" 3 "7+ years" ;
label define PMALESTF  -9 "NO DATA" -3 "MISSING" 1 "0-33%" 2 "34-50%"
                       3 "51-100%" ;
label define PMINOSTF  -9 "NO DATA" -3 "MISSING" 1 "0-33%" 2 "34-66%"
                       3 "67-100%" ;
label define ANYCASE   -9 "NO DATA" 1 "Yes" 2 "No" ;
label define FTEMED    -9 "NO DATA" -3 "MISSING" ;
label define FTECOUNS  -9 "NO DATA" -3 "MISSING" ;
label define FTEADMIN  -9 "NO DATA" -3 "MISSING" ;
label define CTENURE   -9 "NO DATA" ;
label define CADCASES  -9 "NO DATA" ;
label define COLGRAD   -9 "NO DATA" ;
label define CGENDER   -9 "NO DATA" ;
label define CGENMTCH  -9 "NO DATA" ;
label define CRACE     -9 "NO DATA" ;
label define CRACMTCH  -9 "NO DATA" ;
label define CADTRAIN  -9 "NO DATA" ;
label define SVCELSW   -9 "NO DATA" 1 "Yes" 2 "No" ;
label define REVENUE   -9 "NO DATA" -3 "MISSING" ;
label define PCTNOPAY  -9 "NO DATA" -3 "MISSING" 1 "0-50%" 2 "51-99%"
                       3 "100%" ;
label define TOTADMIT  -9 "NO DATA" 1 "0-100" 2 "101-250" 3 "251+" ;
label define AFRADMIT  -9 "NO DATA" -3 "MISSING" 1 "0-10" 2 "11-100"
                       3 "More than 100" ;
label define HSPADMIT  -9 "NO DATA" 1 "0-5" 2 "6-50" 3 "More than 50" ;
label define FEMADMIT  -9 "NO DATA" -3 "MISSING" 1 "0" 2 "1-50"
                       3 "More than 50" ;
label define O21ADM    -9 "NO DATA" -3 "MISSING" 1 "0-30" 2 "31-100"
                       3 "More than 100" ;
label define ACTCASE   -9 "NO DATA" 1 "1-25" 2 "26-100" 3 "More than 100" ;
label define INPHASE   -9 "NO DATA" 1 "Yes" 2 "No" ;
label define EXPHASE   -9 "NO DATA" 1 "Yes" 2 "No" ;
label define PTMATCH   -9 "NO DATA" 1 "Yes" 2 "No" ;
label define FREQCOUN  -9 "NO DATA" 1 "Less than once per week"
                       2 "Once per week" 3 "More than once per week" ;
label define ENVCHANG  -9 "NO DATA" 1 "Yes" 2 "No" ;
label define FAMPAR    -9 "NO DATA" 1 "Yes" 2 "No" ;
label define SELFIMAG  -9 "NO DATA" 1 "Yes" 2 "No" ;
label define URINFREQ  -9 "NO DATA" -3 "MISSING" 1 "Two or fewer"
                       2 "Three or more" ;
label define ACADEMIC  -9 "NO DATA" 1 "Yes" 2 "No" ;
label define VOCTRAIN  -9 "NO DATA" 1 "Yes" 2 "No" ;
label define MEDICAL   -9 "NO DATA" 1 "Yes" 2 "No" ;
label define PSYCHIAT  -9 "NO DATA" 1 "Yes" 2 "No" ;
label define PREGNAN   -9 "NO DATA" 1 "Yes" 2 "No" ;
label define CRSLFEST  -9 "NO DATA" ;
label define CRENVCHG  -9 "NO DATA" ;
label define CRCONBEH  -9 "NO DATA" ;
label define CRSOCSKL  -9 "NO DATA" ;
label define CRINFO    -9 "NO DATA" ;
label define CRJOBED   -9 "NO DATA" ;
label define CRMEDIC   -9 "NO DATA" ;
label define CR12STEP  -9 "NO DATA" ;
label define CRPSYCH   -9 "NO DATA" ;
label define CRPUNISH  -9 "NO DATA" ;
label define CRSPIRIT  -9 "NO DATA" ;
label define CRTSTING  -9 "NO DATA" ;


#delimit cr


/***************************************************************************

 Section 4: Missing Values

 This section will replace numeric missing values (i.e., -9) with generic
 system missing ".".  By default the code in this section is commented out.
 Users wishing to apply the generic missing values should remove the comment
 at the beginning and end of this section.  Note that Stata allows you to
 specify up to 27 unique missing value codes.

****************************************************************/

/*
replace CASEID = . if (CASEID <= -1 )
replace NUSDUID = . if (NUSDUID <= -1 )
replace DIRCOLL = . if (DIRCOLL <= -1 )
replace DIRGRAD = . if (DIRGRAD <= -1 )
replace DIRCRED = . if (DIRCRED <= -1 )
replace DIRYEARS = . if (DIRYEARS <= -1 )
replace DIRSEX = . if (DIRSEX <= -1 )
replace DIRETHNI = . if (DIRETHNI <= -1 )
replace YRSKEYP1 = . if (YRSKEYP1 <= -1 )
replace YRSKEYP2 = . if (YRSKEYP2 <= -1 )
replace PMALESTF = . if (PMALESTF <= -1 )
replace PMINOSTF = . if (PMINOSTF <= -1 )
replace ANYCASE = . if (ANYCASE <= -1 )
replace FTEMED = . if (FTEMED <= -1 )
replace FTECOUNS = . if (FTECOUNS <= -1 )
replace FTEADMIN = . if (FTEADMIN <= -1 )
replace CTENURE = . if (CTENURE <= -1.0 )
replace CADCASES = . if (CADCASES <= -1.0 )
replace COLGRAD = . if (COLGRAD <= -1.0 )
replace CGENDER = . if (CGENDER <= -1.0 )
replace CGENMTCH = . if (CGENMTCH <= -1.0 )
replace CRACE = . if (CRACE <= -1.0 )
replace CRACMTCH = . if (CRACMTCH <= -1.0 )
replace CADTRAIN = . if (CADTRAIN <= -1.0 )
replace SVCELSW = . if (SVCELSW <= -1 )
replace REVENUE = . if (REVENUE <= -1 )
replace PCTNOPAY = . if (PCTNOPAY <= -1 )
replace TOTADMIT = . if (TOTADMIT <= -1 )
replace AFRADMIT = . if (AFRADMIT <= -1 )
replace HSPADMIT = . if (HSPADMIT <= -1 )
replace FEMADMIT = . if (FEMADMIT <= -1 )
replace O21ADM = . if (O21ADM <= -1 )
replace ACTCASE = . if (ACTCASE <= -1 )
replace INPHASE = . if (INPHASE <= -1 )
replace EXPHASE = . if (EXPHASE <= -1 )
replace PTMATCH = . if (PTMATCH <= -1 )
replace FREQCOUN = . if (FREQCOUN <= -1 )
replace ENVCHANG = . if (ENVCHANG <= -1 )
replace FAMPAR = . if (FAMPAR <= -1 )
replace SELFIMAG = . if (SELFIMAG <= -1 )
replace URINFREQ = . if (URINFREQ <= -1 )
replace ACADEMIC = . if (ACADEMIC <= -1 )
replace VOCTRAIN = . if (VOCTRAIN <= -1 )
replace MEDICAL = . if (MEDICAL <= -1 )
replace PSYCHIAT = . if (PSYCHIAT <= -1 )
replace PREGNAN = . if (PREGNAN <= -1 )
replace CRSLFEST = . if (CRSLFEST <= -1.0000 )
replace CRENVCHG = . if (CRENVCHG <= -1.0000 )
replace CRCONBEH = . if (CRCONBEH <= -1.0000 )
replace CRSOCSKL = . if (CRSOCSKL <= -1.0000 )
replace CRINFO = . if (CRINFO <= -1.0000 )
replace CRJOBED = . if (CRJOBED <= -1.0000 )
replace CRMEDIC = . if (CRMEDIC <= -1.0000 )
replace CR12STEP = . if (CR12STEP <= -1.0000 )
replace CRPSYCH = . if (CRPSYCH <= -1.0000 )
replace CRPUNISH = . if (CRPUNISH <= -1.0000 )
replace CRSPIRIT = . if (CRSPIRIT <= -1.0000 )
replace CRTSTING = . if (CRTSTING <= -1.0000 )


*/
/********************************************************************

 Section 5: Save Outfile

  This section saves out a Stata system format file.  There is no reason to
  modify it if the macros in Section 1 were specified correctly.

*********************************************************************/

save `outfile', replace

